Struct Builder

pub struct Builder {
    pub reset_stream_duration: Duration,
    pub reset_stream_max: usize,
    pub pending_accept_reset_stream_max: usize,
    pub settings: Settings,
    pub initial_target_connection_window_size: Option<u32>,
    pub max_send_buffer_size: usize,
}

Fields

reset_stream_duration: Duration

Time to keep locally reset streams around before reaping.

reset_stream_max: usize

Maximum number of locally reset streams to keep at a time.

pending_accept_reset_stream_max: usize

Maximum number of remotely reset streams to allow in the pending accept queue.

settings: Settings

Initial Settings frame to send as part of the handshake.

initial_target_connection_window_size: Option<u32>

Initial target window size for new connections.

max_send_buffer_size: usize

Maximum amount of bytes to “buffer” for writing per stream.

Implementations

Source

impl Builder

pub fn new() -> Builder

pub fn initial_window_size(&mut self, size: u32) -> &mut Self

pub fn initial_connection_window_size(&mut self, size: u32) -> &mut Self

pub fn max_frame_size(&mut self, max: u32) -> &mut Self

pub fn max_header_list_size(&mut self, max: u32) -> &mut Self

pub fn max_concurrent_streams(&mut self, max: u32) -> &mut Self

pub fn max_concurrent_reset_streams(&mut self, max: usize) -> &mut Self

pub fn max_pending_accept_reset_streams(&mut self, max: usize) -> &mut Self

pub fn max_send_buffer_size(&mut self, max: usize) -> &mut Self

pub fn reset_stream_duration(&mut self, dur: Duration) -> &mut Self

pub fn enable_connect_protocol(&mut self) -> &mut Self

pub fn connection<T>(self, io: T) -> H2Connection<T>
where T: AsyncRead + AsyncWrite + Unpin,